.. _documentation:

.. module:: sympy

Welcome to SymPy's documentation!
----------------------------------

A `PDF version of these docs <https://github.com/sympy/sympy/releases>`_ is also available.

`SymPy <https://sympy.org>`_ is a Python library for symbolic mathematics.
If you are new to SymPy, start with the :ref:`introductory tutorial <intro-tutorial>`.

This is the central page for all of SymPy's documentation.

==================================================================

:ref:`Installation <installation>`
----------------------------------

Instructions on how to install SymPy.

:ref:`Tutorials <tutorials>`
----------------------------

Tutorials are the best place to start for anyone new to SymPy or one of
SymPy's features.

:ref:`How-to Guides <guides>`
-----------------------------

How-to guides are step-by-step instructions on how to do specific tasks.

:ref:`Explanations <explanations>`
----------------------------------

Explanations provide in-depth discussions about select SymPy features. These
topic guides talk about things like the motivation behind design decisions,
technical implementation details, and opinionated recommendations.

:ref:`API Reference <reference>`
--------------------------------

The API reference is a detailed description of the SymPy API. Every SymPy
function and class is enumerated here with detailed information on what each
function does.

:ref:`Contributing <contributing>`
----------------------------------

The contributing guide goes over the details necessary to contribute to SymPy.
See also the full `Development Workflow
<https://github.com/sympy/sympy/wiki/Development-workflow>`_ guide on the
SymPy wiki.

.. toctree::
   :hidden:

   install.md
   tutorials/index.rst
   guides/index.rst
   explanation/index.rst
   reference/index.rst
   contributing/index.rst
